@@ -10,13 +10,13 @@ from pathlib import Path
 
 class CommonData(InputData):
     # waste Materials
-    WasteMaterials = ['CompFeed', 'CompRes', 'CompFin', 'Digestate',
-                      'MSW', 'C&DWaste', 'MedWaste', 'MRFRes', 'CombRes',
+    WasteMaterials = ['FoodWaste', 'Compost', 'Digestate',
+                      'MSW', 'CombustionResiduals', 'CompostResiduals',
                       'ContaminatedSoil',
-                      'ContactWater', 'LFLeachate', 'ContaminatedWater',
-                      'DewWWTSol', 'DryWWTSol', 'WWTSol',
-                      'SCWO_Steam', 'SCWO_Slurry',
-                      'SpentGAC', 'ROConc']
+                      'LFLeachate', 'ContaminatedWater', 'ContactWater', 'WWTEffluent',
+                      'RawWWTSolids', 'DewateredWWTSolids', 'DriedWWTSolids', 'WWTSolids',
+                      'SCWOSteam', 'SCWOSlurry',
+                      'SpentGAC', 'ROConcentrate']
 
     # PFAS Index
     PFAS_Index = ['Summed PFAS', 'PFOA', 'PFOS', 'PFAS#4', 'PFAS#5', 'PFAS#6',
