@@ -10,6 +10,7 @@ from PySide2.QtWebEngineWidgets import QWebEngineView, QWebEngineDownloadItem, Q
 from .Table_from_pandas import *
 from . import PFAS_SAT_ui
 from . import MC_ui
+from . import SA_ui
 from . import HelpGuide_ui
 from .Workers import Worker_MC, Worker_Plot
 
@@ -35,7 +36,7 @@ from .. IncomFlow import IncomFlow
 from .. CommonData import CommonData
 from .. Inventory import Inventory
 from .. Project import Project
-from .. ProcessModelsMeta import ProcessModelsMeta
+from .. ProcessModelsMetaData import ProcessModelsMetaData
 
 # Import matplotlib
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
@@ -55,12 +56,14 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         self.SYS_tab.setDisabled(True)
         self.FA_tab.setDisabled(True)
         self.MC_tab.setDisabled(True)
+        self.SA_tab.setDisabled(True)
                 
         self.WM_tab_init_status = False
         self.PM_tab_init_status = False
         self.SYS_tab_init_status = False
         self.FA_tab_init_status = False
         self.MC_tab_init_status = False
+        self.SA_tab_init_status = False
         
         ### Menu
         self.actionHelp_Gui.triggered.connect(self.Help_Gui_func)
@@ -87,14 +90,15 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         else:
             self.IncomFlow = IncomFlow()
             
-            self.ListOfProcessModels = list(ProcessModelsMeta.keys())
+            self.ListOfProcessModels = list(ProcessModelsMetaData.keys())
             self.AllProcessModels = {}
             for P in self.ListOfProcessModels:
                 self.AllProcessModels[P]={}
                 self.AllProcessModels[P]['Default']=True
                 self.AllProcessModels[P]['InputDataPath']=None
+                self.AllProcessModels[P]['Name']= ProcessModelsMetaData[P]['Name']
                 self.AllProcessModels[P]['InputType']=[]
-                for flow in ProcessModelsMeta[P]['InputType']:
+                for flow in ProcessModelsMetaData[P]['InputType']:
                     self.AllProcessModels[P]['InputType'].append(flow)
             
             self.import_PM_init_SYS()
@@ -112,7 +116,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
             self.IncomFlow = IncomFlow()
             self.WM_Combo.clear()
             self.WM_Combo.currentTextChanged.connect(self.Load_Waste_Prop_func)
-            self.WM_Combo.addItems(self.IncomFlow.WasteMaterials)
+            self.WM_Combo.addItems(self.IncomFlow.WasteMaterialsFullName)
             
             self.Clear_WM_uncert.clicked.connect(self.Clear_WM_Uncert_func)
             self.Update_WM_prop.clicked.connect(self.Update_WM_prop_func)
@@ -123,7 +127,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
     
     @QtCore.Slot(str)
     def Load_Waste_Prop_func(self,waste):
-        data = self.IncomFlow.InputData.Data[:][(self.IncomFlow.InputData.Data['Dictonary_Name']== waste) | (self.IncomFlow.InputData.Data['Dictonary_Name']==waste+'_PFAS')]
+        data = self.IncomFlow.InputData.Data[:][(self.IncomFlow.InputData.Data['Category']== waste) | (self.IncomFlow.InputData.Data['Category']==waste+' PFAS Concentration')]
         Waste_Prop_model = Table_from_pandas_editable(data)
         self.WM_table_prop.setModel(Waste_Prop_model)
         self.WM_table_prop.resizeColumnsToContents()
@@ -150,23 +154,31 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
     def init_PM_tab_func(self):
         if not self.PM_tab_init_status:
             self.PM_tab.setEnabled(True)
+            
+            # Disable flows that are not modeled.
+            self.Med_Waste.setDisabled(True)
+            self.MOSP.setDisabled(True)
+            self.AutoShredRes.setDisabled(True)
+
             self._InputKey = {'MSW': self.MSW,
                             'C&DWaste': self.C_D_Waste,
                             'Med_Waste': self.Med_Waste,
                             'MOSP': self.MOSP,
-                            'CompFeed': self.CompFeed,
-                            'CompFin': self.CompFin,
+                            'FoodWaste': self.FW,
+                            'Compost': self.Compost,
                             'Digestate': self.Digestate,
-                            'CompRes': self.CompRes,
+                            'CompostResiduals': self.CompRes,
                             'MRFRes': self.MRFRes,
-                            'CombRes': self.CombRes,
+                            'CombustionResiduals': self.CombRes,
                             'AutoShredRes': self.AutoShredRes,
                             'ContaminatedWater': self.ContWater,
                             'ContaminatedSoil': self.ContSoil,
-                            'DewWWTSol': self.DewWWTSol,
-                            'DryWWTSol': self.DryWWTSol,
-                            'WWTSol': self.WWTSol,
-                            'ROConc': self.ROC,
+                            'WWTEffluent': self.WWTEffluent,
+                            'DewateredWWTSolids': self.DewWWTSol,
+                            'DriedWWTSolids': self.DryWWTSol,
+                            'RawWWTSolids': self.RawWWTSol,
+                            'WWTSolids': self.WWTSol,
+                            'ROConcentrate': self.ROC,
                             'LFLeachate': self.LFLeach,
                             'ContactWater': self.ContactWater,
                             'Solidi_Waste': self.Solidi_Waste,
@@ -176,19 +188,24 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
             for CheckBox in self._InputKey.values():
                 CheckBox.setChecked(False)
     
-            self.ListOfProcessModels = list(ProcessModelsMeta.keys())
+            self.ListOfProcessModels = list(ProcessModelsMetaData.keys())
             self.AllProcessModels = {}
             for P in self.ListOfProcessModels:
                 self.AllProcessModels[P]={}
                 self.AllProcessModels[P]['Default']=True
                 self.AllProcessModels[P]['InputDataPath']=None
+                self.AllProcessModels[P]['Name']= ProcessModelsMetaData[P]['Name']
                 self.AllProcessModels[P]['InputType']=[]
-                for flow in ProcessModelsMeta[P]['InputType']:
+                for flow in ProcessModelsMetaData[P]['InputType']:
                     self.AllProcessModels[P]['InputType'].append(flow)
-                
+            
+            self.ProcessNamehelper={}
+            for key,val in ProcessModelsMetaData.items():
+                self.ProcessNamehelper[val['Name']] = key
+
             self.ProcModel_Combo.clear()
             self.ProcModel_Combo.currentTextChanged.connect(self.load_PM_metadata)
-            self.ProcModel_Combo.addItems(self.ListOfProcessModels)
+            self.ProcModel_Combo.addItems(list(self.ProcessNamehelper.keys()))
             
             self.ProcModel_Brow_Input.clicked.connect(self.select_file(self.ProcModel_Input_path,"CSV (*.csv)"))
             self.ProcModel_update.clicked.connect(self.update_PM_metadata)
@@ -201,6 +218,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
                 
     @QtCore.Slot(str)
     def load_PM_metadata(self,process):
+        process = self.ProcessNamehelper[process]
         self.ProcModel_def_input.setChecked(self.AllProcessModels[process]['Default'])
         
         if self.AllProcessModels[process]['InputDataPath']:
@@ -216,7 +234,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
     
     @QtCore.Slot()
     def update_PM_metadata(self):
-        Process = self.ProcModel_Combo.currentText()
+        Process = self.ProcessNamehelper[self.ProcModel_Combo.currentText()]
         self.AllProcessModels[Process]['Default']=self.ProcModel_def_input.isChecked()
         if self.ProcModel_user_input.isChecked():
             self.AllProcessModels[Process]['InputDataPath']= self.ProcModel_Input_path.text()
@@ -227,7 +245,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         for flow,CheckBox in self._InputKey.items():
             if CheckBox.isChecked():
                 self.AllProcessModels[Process]['InputType'].append(flow)
-        self.msg_popup('Updata Process Model','The input data for the process model ({}) is updated successfully.'.format(Process),'Information')
+        self.msg_popup('Updata Process Model','The input data for the process model ({}) is updated successfully.'.format(self.ProcModel_Combo.currentText()),'Information')
 
     @QtCore.Slot()
     def clear_PM_metadata(self):
@@ -242,12 +260,13 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         self.Inventory = Inventory()
         for proc in self.AllProcessModels:
             clas_name= proc
-            clas_file=  ProcessModelsMeta[proc]['File'].split('.')[0]
+            clas_file=  ProcessModelsMetaData[proc]['File'].split('.')[0]
             module = importlib.import_module('PFAS_SAT.'+clas_file)
             model = module.__getattribute__(clas_name)
             self.AllProcessModels[proc]['Model'] = model(input_data_path=self.AllProcessModels[proc]['InputDataPath'],
                                                          CommonDataObjct=self.CommonData,
-                                                         InventoryObject=self.Inventory)
+                                                         InventoryObject=self.Inventory,
+                                                         Name=self.AllProcessModels[proc]['Name'])
         
         print('\n \n All the process models: \n {} \n\n'.format(self.AllProcessModels))
         self.init_SYS_tab_func()
@@ -264,7 +283,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         if not self.SYS_tab_init_status:
             self.SYS_tab.setEnabled(True)
             self.FU.clear()
-            self.FU.addItems(self.IncomFlow.WasteMaterials)
+            self.FU.addItems(self.IncomFlow.WasteMaterialsFullName)
             self.FU_unit.setText('Kg/Year')
             self.FU_amount.setText('1000')
             self.reset.clicked.connect(self.clear_project_setup)
@@ -273,6 +292,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
             self.Update_Flowparams.clicked.connect(self.set_flow_params_func)
             self.FA_Btm.clicked.connect(self.init_FA_tab_func)
             self.MC_Btm.clicked.connect(self.init_MC_tab_func)
+            self.SA_Btm.clicked.connect(self.init_SA_tab_func)
             
             self.init_project_status = True
             
@@ -292,7 +312,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
             for P in Process_set:
                 self.Process_set_dict[P] = QtWidgets.QCheckBox(self.ProcessSetFrame)
                 self.Process_set_dict[P].setObjectName(P)
-                self.Process_set_dict[P].setText(P)
+                self.Process_set_dict[P].setText(self.AllProcessModels[P]['Name'])
                 self.Process_set_dict[P].setChecked(True)
                 self.Layout.addWidget(self.Process_set_dict[P],row,col)
                 col+=1
@@ -427,7 +447,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         self.MC_tab.setEnabled(True)
         self.PFAS_SAT_1.setCurrentWidget(self.MC_tab)    
         self.MC_Model.clear()
-        self.MC_Model.addItems(['IncomFlow']+list(self.Project.ProcessSet))
+        self.MC_Model.addItems(['IncomFlow']+[self.Project.ProcessModels[p]['Name'] for p in self.Project.ProcessSet])
     
     @QtCore.Slot(str)
     def show_inputdata(self,process):
@@ -436,7 +456,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         elif process == 'IncomFlow':
             self._uncertain_data = self.IncomFlow.InputData.Data
         else:
-            self._uncertain_data = self.Project.ProcessModels[process]['Model'].InputData.Data
+            self._uncertain_data = self.Project.ProcessModels[self.Project._ProcessNameRef[process]]['Model'].InputData.Data
             
         model = Table_from_pandas_editable(self._uncertain_data)
         self.MC_Uncertain_table.setModel(model)
@@ -455,7 +475,7 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         if process == 'IncomFlow':
             self.IncomFlow.InputData.Update_input(self.MC_Uncertain_table.model()._data)
         else:
-            self.Project.ProcessModels[process]['Model'].InputData.Update_input(self.MC_Uncertain_table.model()._data)
+            self.Project.ProcessModels[self.Project._ProcessNameRef[process]]['Model'].InputData.Update_input(self.MC_Uncertain_table.model()._data)
         
         self.msg_popup('Updata Input Data','The data is updated successfully.','Information')
 
@@ -557,8 +577,55 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         self.MC_Widget.Update_plot.clicked.connect(self.mc_plot_func)
         self.MC_Widget.Update_dist_fig.clicked.connect(self.mc_plot_dist_func)
         
+        ### Correlation tab
+        self.corr_data = self.MC_results[self.MC_results.columns[1:]].corr(method='pearson')
+        
+        self._MC_results_index = ['Water (10e-6g/year)','Soil (10e-6g/year)','Air (10e-6g/year)','Destroyed (10e-6g/year)','Stored (10e-6g/year)']
+
+        # Correlation plot
+        self.MC_Widget.Corr_param.addItems(self._MC_results_index)
+        self.MC_Widget.Corr_btm.clicked.connect(self.corr_plot_func)
+        
+        #Figure initialization _ correlation plot
+        self.fig_corr = Figure(figsize=(4, 5), dpi=65, facecolor=(1, 1, 1), edgecolor=(0, 0, 0))
+        self.canvas_corr = FigureCanvas(self.fig_corr)
+        toolbar = NavigationToolbar(self.canvas_corr, self)
+        lay = QtWidgets.QVBoxLayout(self.MC_Widget.Corr_plot)
+        lay.addWidget(toolbar)
+        lay.addWidget(self.canvas_corr)        
+        
         Dialog.show()
         Dialog.exec_()
+
+    @QtCore.Slot()
+    def corr_plot_func(self):
+        self.fig_corr.clear()
+        self.ax_plot_corr = self.fig_corr.add_subplot(111)
+    
+        #ploting the DataFrame
+        param=list(self.corr_data.columns)
+        for x in self._MC_results_index:
+            param.remove(x)
+
+        corr_data_plot = self.corr_data[self.MC_Widget.Corr_param.currentText()][param]
+        sorted_corr=corr_data_plot.abs().sort_values()
+
+        if len(sorted_corr.index) <= 10:
+            index = sorted_corr.index
+        else:
+            index = sorted_corr.index[0:10]
+        
+        self.ax_plot_corr=corr_data_plot[index].plot(kind='barh',
+                                                     ax=self.ax_plot_corr)
+        #set lables
+        self.ax_plot_corr.set_xlabel('Correlation with {}'.format(self.MC_Widget.Corr_param.currentText()), fontsize=18)
+        self.ax_plot_corr.set_xlim(-1,1)
+        self.ax_plot_corr.tick_params(axis='both', which='major', labelsize=18,rotation='auto')
+        self.ax_plot_corr.tick_params(axis='both', which='minor', labelsize=16,rotation='auto')
+
+        #set margins
+        self.canvas_corr.draw()
+        self.fig_corr.set_tight_layout(True)
         
     @QtCore.Slot()
     def mc_plot_func(self):
@@ -613,7 +680,176 @@ class MyQtApp(PFAS_SAT_ui.Ui_PFAS_SAT, QtWidgets.QMainWindow):
         #set margins
         self.canvas_plot_dist_mc.draw()
         self.fig_plot_dist_mc.set_tight_layout(True)
+
+#%%  SA tab          
+# =============================================================================
+# =============================================================================
+    ### Sensitivity analysis
+# =============================================================================
+# =============================================================================
+    @QtCore.Slot()
+    def init_SA_tab_func(self):
+        if not self.SA_tab_init_status:
+            self.SA_tab.setEnabled(True)
+            self.SA_PFAS.clear()
+            self.SA_PFAS.addItems(['All']+[i for i in self.CommonData.PFAS_Index])
+            self.SA_Model.currentTextChanged.connect(self.load_categories_func)
+            self.SA_Category.currentTextChanged.connect(self.load_parameters_func)
+            self.SA_Parameter.currentTextChanged.connect(self.load_paramInfo_func)
+            self.SA_Run.clicked.connect(self.SA_Run_func)
+            self.SA_Save.clicked.connect(self.SA_save_file())
+            self.SA_Clear.clicked.connect(self.SA_Clear_func)
+            self.SA_Plot.clicked.connect(self.show_sa_res_func)
+
+        self.PFAS_SAT_1.setCurrentWidget(self.SA_tab)
+        self.SA_Model.clear()
+        self.SA_Model.addItems(['...', 'IncomFlow']+[self.Project.ProcessModels[p]['Name'] for p in self.Project.ProcessSet])
+        self.SA_PFAS.setCurrentIndex(0)
+
+    @QtCore.Slot(str)
+    def load_categories_func(self,process):
+        if process == '...' or process == '':
+            categories = ['...']
+        elif process == 'IncomFlow':
+            categories = ['...']+list(self.IncomFlow.InputData.Input_dict.keys())
+        else:
+            categories = ['...']+list(self.Project.ProcessModels[self.Project._ProcessNameRef[process]]['Model'].InputData.Input_dict.keys())
         
+        self.SA_Category.clear()
+        self.SA_Category.addItems(categories)
+
+    @QtCore.Slot(str)
+    def load_parameters_func(self,category):
+        if category == '...' or category == '':
+            parameters = ['...']
+        elif self.SA_Model.currentText() == 'IncomFlow':
+            parameters = ['...']+['{}: {}'.format(key, val['Name']) for key,val  in self.IncomFlow.InputData.Input_dict[category].items()]
+        else:
+            parameters = ['...']+['{}: {}'.format(key, val['Name']) for key,val in self.Project.ProcessModels[self.Project._ProcessNameRef[self.SA_Model.currentText()]]['Model'].InputData.Input_dict[category].items()]
+        
+        self.SA_Parameter.clear()
+        self.SA_Parameter.addItems(parameters)       
+
+    @QtCore.Slot(str)
+    def load_paramInfo_func(self,parameter):
+        if parameter == '...' or parameter == '':
+            info= ''
+        elif self.SA_Model.currentText() == 'IncomFlow':
+            param = parameter.split(':')[0]
+            param_dict = self.IncomFlow.InputData.Input_dict[self.SA_Category.currentText()][param]
+            info = str()
+            for key in ['amount', 'uncertainty_type', 'loc', 'scale', 'minimum', 'maximum', 'Comment', 'Reference']:
+                val = param_dict[key]
+                if isinstance(val, str):
+                    info += key + ': ' + str(val) + '\n'
+                elif not np.isnan(val):
+                    info += key + ': ' + str(val) + '\n'                    
+        else:
+            param = parameter.split(':')[0]
+            param_dict = self.Project.ProcessModels[self.Project._ProcessNameRef[self.SA_Model.currentText()]]['Model'].InputData.Input_dict[self.SA_Category.currentText()][param]
+            info = str()
+            for key in ['amount', 'uncertainty_type', 'loc', 'scale', 'minimum', 'maximum', 'Comment', 'Reference']:
+                val = param_dict[key]
+                if isinstance(val, str):
+                    info += key + ': ' + str(val) + '\n'
+                elif not np.isnan(val):
+                    info += key + ': ' + str(val) + '\n'
+        self.SA_ParamInfo.setText(info)        
+
+    @QtCore.Slot(str)
+    def SA_Run_func(self):
+        self.Project.setup_MC(self.IncomFlow)
+        if self.SA_Model.currentText() == 'IncomFlow':
+            model = 'IncomFlow'
+        else:
+            model = self.Project._ProcessNameRef[self.SA_Model.currentText()]
+
+        SA_Res_raw = self.Project.SensitivityAnalysis(Model=model,
+                                                      Category=self.SA_Category.currentText(),
+                                                      Paramter=str.split(self.SA_Parameter.currentText(),':')[0],
+                                                      Start=float(self.SA_Start.text()),
+                                                      Stop=float(self.SA_Stop.text()),
+                                                      Nstep=int(self.SA_NStep.text()),
+                                                      TypeOfPFAS=self.SA_PFAS.currentText())
+        self.SA_Res = self.Project.Result_to_DF(SA_Res_raw)
+    
+        ### Data Tab
+        SA_Res_table_model = Table_from_pandas(self.SA_Res)
+        self.SA_Results.setModel(SA_Res_table_model)
+        self.SA_Results.resizeColumnsToContents()
+        self.SA_Results.installEventFilter(self)
+        self.SA_Results.setSortingEnabled(True)
+
+    @QtCore.Slot()  # select file and read the name of it. Import the name to the LineEdit.
+    def SA_save_file(self):
+        fileDialog = QtWidgets.QFileDialog()
+        def helper():
+            file_name = str(fileDialog.getSaveFileName(filter="CSV (*.csv)")[0])
+            if file_name:
+                self.SA_Res.to_csv(file_name)
+        return(helper) 
+
+    @QtCore.Slot(str)
+    def SA_Clear_func(self):
+        self.SA_Model.setCurrentIndex(0)
+        self.SA_Start.clear()
+        self.SA_Stop.clear()
+        self.SA_NStep.clear()
+        self.SA_ParamInfo.clear()
+        self.SA_Results.setModel(Table_from_pandas(pd.DataFrame()))
+        self.SA_PFAS.setCurrentIndex(0)
+
+#%% SA results window          
+# =============================================================================
+# =============================================================================
+    ### Define SA results window
+# =============================================================================
+# =============================================================================
+    @QtCore.Slot()
+    def show_sa_res_func(self):
+        Dialog = QtWidgets.QDialog()
+        self.SA_Widget = SA_ui.Ui_SA_Plot()
+        self.SA_Widget.setupUi(Dialog)
+        
+        ### Plot tab
+        #Figure initialization _ plot
+        self.fig_plot_sa = Figure(figsize=(4, 5), dpi=65, facecolor=(1, 1, 1), edgecolor=(0, 0, 0))
+        self.canvas_plot_sa = FigureCanvas(self.fig_plot_sa)
+        toolbar = NavigationToolbar(self.canvas_plot_sa, self)
+        lay = QtWidgets.QVBoxLayout(self.SA_Widget.plot)
+        lay.addWidget(toolbar)
+        lay.addWidget(self.canvas_plot_sa)
+        
+        self.SA_Widget.y_axis.addItems([str(x) for x in self.SA_Res.columns])
+        self.SA_Widget.x_axis.addItems([str(x) for x in self.SA_Res.columns])
+    
+        ### Connect the push bottoms
+        self.SA_Widget.Update_plot.clicked.connect(self.sa_plot_func)
+        
+        Dialog.show()
+        Dialog.exec_()
+        
+    @QtCore.Slot()
+    def sa_plot_func(self):
+        self.fig_plot_sa.clear()
+        self.ax_plot_sa = self.fig_plot_sa.add_subplot(111)
+    
+        #ploting the DataFrame        
+        self.ax_plot_sa=self.SA_Res.plot(kind='scatter',
+                                        x=self.SA_Res.columns[self.SA_Widget.x_axis.currentIndex()],
+                                        y=self.SA_Res.columns[self.SA_Widget.y_axis.currentIndex()],
+                                        ax=self.ax_plot_sa)
+        #set lables
+        self.ax_plot_sa.set_title(str(self.IncomFlow.Inc_flow.FlowType), fontsize=18)
+        self.ax_plot_sa.set_ylabel(self.SA_Widget.y_axis.currentText(), fontsize=18)
+        self.ax_plot_sa.set_xlabel(self.SA_Widget.x_axis.currentText(), fontsize=18)
+        self.ax_plot_sa.tick_params(axis='both', which='major', labelsize=18,rotation='auto')
+        self.ax_plot_sa.tick_params(axis='both', which='minor', labelsize=16,rotation='auto')
+
+        #set margins
+        self.canvas_plot_sa.draw()
+        self.fig_plot_sa.set_tight_layout(True)
+
 #%% General Functions          
 # =============================================================================
 # =============================================================================
