@@ -12,12 +12,21 @@ class IncomFlow():
     def __init__(self, input_data_path=None):
         self.InputData = IncomFlowInput(input_data_path)
         wasteMaterils = self.InputData.Data['Dictonary_Name'].unique()
+        wasteMaterilsFullName = self.InputData.Data['Category'].unique()
         self.WasteMaterials = []
-        for i in wasteMaterils:
-            if 'PFAS' not in i:
-                self.WasteMaterials.append(i)
+        self.WasteMaterialsFullName = []
+        self.WasteMaterialsNameHelper = {}
+
+        for i in range(len(wasteMaterils)):
+            if 'PFAS' not in wasteMaterils[i]:
+                self.WasteMaterials.append(wasteMaterils[i])
+            if 'PFAS' not in wasteMaterilsFullName[i]:
+                self.WasteMaterialsFullName.append(wasteMaterilsFullName[i])
+                self.WasteMaterialsNameHelper[wasteMaterilsFullName[i]] = wasteMaterils[i]
 
     def set_flow(self, flow_name, mass_flow):
+        if flow_name in self.WasteMaterialsNameHelper:
+            flow_name = self.WasteMaterialsNameHelper[flow_name]
         self._flow_name = flow_name
         self._mass_flow = mass_flow
         self.calc()
