@@ -22,6 +22,7 @@ from PFAS_SAT.InputData import InputData
 from PFAS_SAT.CommonData import CommonData
 
 # Import process models
+from PFAS_SAT.ProcessModelsMetaData import ProcessModelsMetaData
 from PFAS_SAT.ProcessModel import ProcessModel
 from PFAS_SAT.Flow import Flow
 from PFAS_SAT.Comp import Comp
@@ -33,7 +34,7 @@ from PFAS_SAT.AdvWWT import AdvWWT
 from PFAS_SAT.ThermalTreatment import ThermalTreatment
 from PFAS_SAT.AD import AD
 from PFAS_SAT.SCWO import SCWO
-
+from PFAS_SAT.SurfaceWaterRelease import SurfaceWaterRelease
 
 __all__ = [
     'MyQtApp',
@@ -52,12 +53,14 @@ __all__ = [
     'ThermalTreatment',
     'AD',
     'SCWO',
+    'SurfaceWaterRelease',
+    'ProcessModelsMetaData',
     'MC',
     'InputData',
     'CommonData'
     ]
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 
 
 class PFAS_SAT():
